@@ -74,6 +74,16 @@ public interface Backup extends Identified {
      */
     Date creationDate();
 
+    /**
+     * The backup modification date.
+     *
+     * @author Pavel Bar <pbar@redhat.com>
+     * @date 28 Jul 2021
+     * @status added
+     * @since 4.4.8
+     */
+    Date modificationDate();
+
     /**
      * A reference to the virtual machine associated with the backup.
      *
