@@ -163,6 +163,14 @@ public interface HostsService {
          */
         @In Boolean activate();
 
+        /**
+         * Indicates if the host should be rebooted after successful installation. The default value is `true`.
+         *
+         * @author Dana Elfassy <delfassy@redhat.com>
+         * @date 3 Feb 2021
+         */
+        @In Boolean reboot();
+
         /**
          * Add a new host to the system providing the host root password. This has been deprecated and provided for backwards compatibility.
          *
@@ -179,7 +187,7 @@ public interface HostsService {
         }
 
         /**
-         * Add a new host to the system providing the ssh password or fingerprint.
+         * Add a new host to the system providing the ssh password, fingerprint or public key.
          *
          * @author Ori Liel <oliel@redhat.com>
          * @date 18 Jan 2017
@@ -190,6 +198,7 @@ public interface HostsService {
             default void inputDetail() {
                 optional(host().ssh().authenticationMethod());
                 optional(host().ssh().fingerprint());
+                optional(host().ssh().publicKey());
                 optional(host().ssh().port());
                 optional(host().ssh().user().password());
                 optional(host().ssh().user().userName());
