@@ -304,6 +304,9 @@ public interface TemplateService {
             optional(template().storageErrorResumeBehaviour());
             optional(template().multiQueuesEnabled());
             optional(template().virtioScsiMultiQueuesEnabled());
+            optional(template().virtioScsiMultiQueues());
+            optional(template().tpmEnabled());
+            optional(template().autoPinningPolicy());
         }
         @In @Out Template template();
 
