@@ -33,6 +33,7 @@ import org.ovirt.engine.sdk4.types.Display;
 import org.ovirt.engine.sdk4.types.ErrorHandling;
 import org.ovirt.engine.sdk4.types.ExternalProvider;
 import org.ovirt.engine.sdk4.types.FencingPolicy;
+import org.ovirt.engine.sdk4.types.FipsMode;
 import org.ovirt.engine.sdk4.types.FirewallType;
 import org.ovirt.engine.sdk4.types.GlusterHook;
 import org.ovirt.engine.sdk4.types.GlusterVolume;
@@ -66,6 +67,7 @@ public class ClusterBuilder {
     private ErrorHandling errorHandling;
     private List<ExternalProvider> externalNetworkProviders;
     private FencingPolicy fencingPolicy;
+    private FipsMode fipsMode;
     private FirewallType firewallType;
     private List<GlusterHook> glusterHooks;
     private Boolean glusterService;
@@ -383,6 +385,12 @@ public class ClusterBuilder {
     }
     
     
+    public ClusterBuilder fipsMode(FipsMode newFipsMode) {
+        fipsMode = newFipsMode;
+        return this;
+    }
+    
+    
     public ClusterBuilder firewallType(FirewallType newFirewallType) {
         firewallType = newFirewallType;
         return this;
@@ -937,6 +945,7 @@ public class ClusterBuilder {
         container.errorHandling(errorHandling);
         container.externalNetworkProviders(externalNetworkProviders);
         container.fencingPolicy(fencingPolicy);
+        container.fipsMode(fipsMode);
         container.firewallType(firewallType);
         container.glusterHooks(glusterHooks);
         container.glusterService(glusterService);
