@@ -23,6 +23,7 @@ import java.util.Collections;
 import java.util.Date;
 import java.util.List;
 import org.ovirt.engine.sdk4.internal.containers.VmBaseContainer;
+import org.ovirt.engine.sdk4.types.AutoPinningPolicy;
 import org.ovirt.engine.sdk4.types.Bios;
 import org.ovirt.engine.sdk4.types.Cluster;
 import org.ovirt.engine.sdk4.types.Console;
@@ -54,6 +55,7 @@ import org.ovirt.engine.sdk4.types.VmStorageErrorResumeBehaviour;
 import org.ovirt.engine.sdk4.types.VmType;
 
 public class VmBaseBuilder {
+    private AutoPinningPolicy autoPinningPolicy;
     private Bios bios;
     private Cluster cluster;
     private String comment;
@@ -97,12 +99,20 @@ public class VmBaseBuilder {
     private StorageDomain storageDomain;
     private VmStorageErrorResumeBehaviour storageErrorResumeBehaviour;
     private TimeZone timeZone;
+    private Boolean tpmEnabled;
     private Boolean tunnelMigration;
     private VmType type;
     private Usb usb;
     private VirtioScsi virtioScsi;
+    private BigInteger virtioScsiMultiQueues;
     private Boolean virtioScsiMultiQueuesEnabled;
     
+    public VmBaseBuilder autoPinningPolicy(AutoPinningPolicy newAutoPinningPolicy) {
+        autoPinningPolicy = newAutoPinningPolicy;
+        return this;
+    }
+    
+    
     public VmBaseBuilder bios(Bios newBios) {
         bios = newBios;
         return this;
@@ -750,6 +760,17 @@ public class VmBaseBuilder {
     }
     
     
+    public VmBaseBuilder tpmEnabled(boolean newTpmEnabled) {
+        tpmEnabled = Boolean.valueOf(newTpmEnabled);
+        return this;
+    }
+    
+    public VmBaseBuilder tpmEnabled(Boolean newTpmEnabled) {
+        tpmEnabled = newTpmEnabled;
+        return this;
+    }
+    
+    
     public VmBaseBuilder tunnelMigration(boolean newTunnelMigration) {
         tunnelMigration = Boolean.valueOf(newTunnelMigration);
         return this;
@@ -799,6 +820,42 @@ public class VmBaseBuilder {
     }
     
     
+    public VmBaseBuilder virtioScsiMultiQueues(int newVirtioScsiMultiQueues) {
+        virtioScsiMultiQueues = BigInteger.valueOf((long) newVirtioScsiMultiQueues);
+        return this;
+    }
+    
+    public VmBaseBuilder virtioScsiMultiQueues(Integer newVirtioScsiMultiQueues) {
+        if (newVirtioScsiMultiQueues == null) {
+            virtioScsiMultiQueues = null;
+        }
+        else {
+            virtioScsiMultiQueues = BigInteger.valueOf(newVirtioScsiMultiQueues.longValue());
+        }
+        return this;
+    }
+    
+    public VmBaseBuilder virtioScsiMultiQueues(long newVirtioScsiMultiQueues) {
+        virtioScsiMultiQueues = BigInteger.valueOf(newVirtioScsiMultiQueues);
+        return this;
+    }
+    
+    public VmBaseBuilder virtioScsiMultiQueues(Long newVirtioScsiMultiQueues) {
+        if (newVirtioScsiMultiQueues == null) {
+            virtioScsiMultiQueues = null;
+        }
+        else {
+            virtioScsiMultiQueues = BigInteger.valueOf(newVirtioScsiMultiQueues.longValue());
+        }
+        return this;
+    }
+    
+    public VmBaseBuilder virtioScsiMultiQueues(BigInteger newVirtioScsiMultiQueues) {
+        virtioScsiMultiQueues = newVirtioScsiMultiQueues;
+        return this;
+    }
+    
+    
     public VmBaseBuilder virtioScsiMultiQueuesEnabled(boolean newVirtioScsiMultiQueuesEnabled) {
         virtioScsiMultiQueuesEnabled = Boolean.valueOf(newVirtioScsiMultiQueuesEnabled);
         return this;
@@ -812,6 +869,7 @@ public class VmBaseBuilder {
     
     public VmBase build() {
         VmBaseContainer container = new VmBaseContainer();
+        container.autoPinningPolicy(autoPinningPolicy);
         container.bios(bios);
         container.cluster(cluster);
         container.comment(comment);
@@ -855,10 +913,12 @@ public class VmBaseBuilder {
         container.storageDomain(storageDomain);
         container.storageErrorResumeBehaviour(storageErrorResumeBehaviour);
         container.timeZone(timeZone);
+        container.tpmEnabled(tpmEnabled);
         container.tunnelMigration(tunnelMigration);
         container.type(type);
         container.usb(usb);
         container.virtioScsi(virtioScsi);
+        container.virtioScsiMultiQueues(virtioScsiMultiQueues);
         container.virtioScsiMultiQueuesEnabled(virtioScsiMultiQueuesEnabled);
         return container;
     }
