@@ -722,6 +722,21 @@ public interface DiskService extends MeasurableService {
      */
     UpdateRequest update();
     
+    /**
+     * Reference to the service that manages the DiskSnapshots.
+     * 
+     * For example, to list all disk snapshots under the disks resource '123':
+     * 
+     * ....
+     * GET /ovirt-engine/api/disks/123/disksnapshots
+     * ....
+     * 
+     * For example, to retrieve a specific disk snapshot '789' under the disk resource '123':
+     * ....
+     * GET /ovirt-engine/api/disks/123/disksnapshots/789
+     * ....
+     */
+    DiskSnapshotsService diskSnapshotsService();
     /**
      * Reference to the service that manages the permissions assigned to the disk.
      */
