@@ -1148,6 +1148,72 @@ public interface VmService extends MeasurableService {
     
     ReorderMacAddressesRequest reorderMacAddresses();
     
+    /**
+     * Sends a reset request to a virtual machine.
+     * 
+     * For example:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/reset
+     * ----
+     * 
+     * The reset action does not take any action specific parameters; therefore, the request body should contain an
+     * empty `action`:
+     * 
+     * [source,xml]
+     * ----
+     * <action/>
+     * ----
+     */
+    public interface ResetRequest extends Request<ResetRequest, ResetResponse> {
+        /**
+         * Indicates if the reset should be performed asynchronously.
+         */
+        ResetRequest async(Boolean async);
+    }
+    
+    /**
+     * Sends a reset request to a virtual machine.
+     * 
+     * For example:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/reset
+     * ----
+     * 
+     * The reset action does not take any action specific parameters; therefore, the request body should contain an
+     * empty `action`:
+     * 
+     * [source,xml]
+     * ----
+     * <action/>
+     * ----
+     */
+    public interface ResetResponse extends Response {
+    }
+    
+    /**
+     * Sends a reset request to a virtual machine.
+     * 
+     * For example:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/reset
+     * ----
+     * 
+     * The reset action does not take any action specific parameters; therefore, the request body should contain an
+     * empty `action`:
+     * 
+     * [source,xml]
+     * ----
+     * <action/>
+     * ----
+     */
+    ResetRequest reset();
+    
     /**
      * This operation sends a shutdown request to a virtual machine.
      * 
