@@ -28,6 +28,10 @@ public interface Checkpoint extends Identified {
     
     boolean parentIdPresent();
     
+    CheckpointState state();
+    
+    boolean statePresent();
+    
     List<Disk> disks();
     
     boolean disksPresent();
