@@ -20,6 +20,7 @@ import java.lang.String;
 import java.math.BigInteger;
 import java.util.Date;
 import java.util.List;
+import org.ovirt.engine.sdk4.types.AutoPinningPolicy;
 import org.ovirt.engine.sdk4.types.Bios;
 import org.ovirt.engine.sdk4.types.Cluster;
 import org.ovirt.engine.sdk4.types.Console;
@@ -51,6 +52,7 @@ import org.ovirt.engine.sdk4.types.VmStorageErrorResumeBehaviour;
 import org.ovirt.engine.sdk4.types.VmType;
 
 public class VmBaseContainer extends IdentifiedContainer implements VmBase {
+    private AutoPinningPolicy autoPinningPolicy;
     private Bios bios;
     private Console console;
     private Cpu cpu;
@@ -85,15 +87,30 @@ public class VmBaseContainer extends IdentifiedContainer implements VmBase {
     private Boolean stateless;
     private VmStorageErrorResumeBehaviour storageErrorResumeBehaviour;
     private TimeZone timeZone;
+    private Boolean tpmEnabled;
     private Boolean tunnelMigration;
     private VmType type;
     private Usb usb;
     private VirtioScsi virtioScsi;
+    private BigInteger virtioScsiMultiQueues;
+    private Boolean virtioScsiMultiQueuesEnabled;
     private Cluster cluster;
     private CpuProfile cpuProfile;
     private Quota quota;
     private StorageDomain storageDomain;
     
+    public AutoPinningPolicy autoPinningPolicy() {
+        return autoPinningPolicy;
+    }
+    
+    public void autoPinningPolicy(AutoPinningPolicy newAutoPinningPolicy) {
+        autoPinningPolicy = newAutoPinningPolicy;
+    }
+    
+    public boolean autoPinningPolicyPresent() {
+        return autoPinningPolicy != null;
+    }
+    
     public Bios bios() {
         return bios;
     }
@@ -580,6 +597,22 @@ public class VmBaseContainer extends IdentifiedContainer implements VmBase {
         return timeZone != null;
     }
     
+    public boolean tpmEnabled() {
+        return tpmEnabled;
+    }
+    
+    public void tpmEnabled(boolean newTpmEnabled) {
+        tpmEnabled = Boolean.valueOf(newTpmEnabled);
+    }
+    
+    public void tpmEnabled(Boolean newTpmEnabled) {
+        tpmEnabled = newTpmEnabled;
+    }
+    
+    public boolean tpmEnabledPresent() {
+        return tpmEnabled != null;
+    }
+    
     public boolean tunnelMigration() {
         return tunnelMigration;
     }
@@ -632,6 +665,50 @@ public class VmBaseContainer extends IdentifiedContainer implements VmBase {
         return virtioScsi != null;
     }
     
+    public BigInteger virtioScsiMultiQueues() {
+        return virtioScsiMultiQueues;
+    }
+    
+    public Byte virtioScsiMultiQueuesAsByte() {
+        return asByte("VmBase", "virtioScsiMultiQueues", virtioScsiMultiQueues);
+    }
+    
+    public Short virtioScsiMultiQueuesAsShort() {
+        return asShort("VmBase", "virtioScsiMultiQueues", virtioScsiMultiQueues);
+    }
+    
+    public Integer virtioScsiMultiQueuesAsInteger() {
+        return asInteger("VmBase", "virtioScsiMultiQueues", virtioScsiMultiQueues);
+    }
+    
+    public Long virtioScsiMultiQueuesAsLong() {
+        return asLong("VmBase", "virtioScsiMultiQueues", virtioScsiMultiQueues);
+    }
+    
+    public void virtioScsiMultiQueues(BigInteger newVirtioScsiMultiQueues) {
+        virtioScsiMultiQueues = newVirtioScsiMultiQueues;
+    }
+    
+    public boolean virtioScsiMultiQueuesPresent() {
+        return virtioScsiMultiQueues != null;
+    }
+    
+    public boolean virtioScsiMultiQueuesEnabled() {
+        return virtioScsiMultiQueuesEnabled;
+    }
+    
+    public void virtioScsiMultiQueuesEnabled(boolean newVirtioScsiMultiQueuesEnabled) {
+        virtioScsiMultiQueuesEnabled = Boolean.valueOf(newVirtioScsiMultiQueuesEnabled);
+    }
+    
+    public void virtioScsiMultiQueuesEnabled(Boolean newVirtioScsiMultiQueuesEnabled) {
+        virtioScsiMultiQueuesEnabled = newVirtioScsiMultiQueuesEnabled;
+    }
+    
+    public boolean virtioScsiMultiQueuesEnabledPresent() {
+        return virtioScsiMultiQueuesEnabled != null;
+    }
+    
     public Cluster cluster() {
         return cluster;
     }
