@@ -70,6 +70,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             return this;
         }
         
+        private Boolean reboot;
+        public AddRequest reboot(Boolean reboot) {
+            this.reboot = reboot;
+            return this;
+        }
+        
         private Boolean undeployHostedEngine;
         public AddRequest undeployHostedEngine(Boolean undeployHostedEngine) {
             this.undeployHostedEngine = undeployHostedEngine;
@@ -86,6 +92,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 if (deployHostedEngine != null) {
                     uriBuilder.addParameter("deploy_hosted_engine", XmlWriter.renderBoolean(deployHostedEngine));
                 }
+                if (reboot != null) {
+                    uriBuilder.addParameter("reboot", XmlWriter.renderBoolean(reboot));
+                }
                 if (undeployHostedEngine != null) {
                     uriBuilder.addParameter("undeploy_hosted_engine", XmlWriter.renderBoolean(undeployHostedEngine));
                 }
@@ -333,6 +342,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             return this;
         }
         
+        private Boolean reboot;
+        public AddUsingRootPasswordRequest reboot(Boolean reboot) {
+            this.reboot = reboot;
+            return this;
+        }
+        
         private Boolean undeployHostedEngine;
         public AddUsingRootPasswordRequest undeployHostedEngine(Boolean undeployHostedEngine) {
             this.undeployHostedEngine = undeployHostedEngine;
@@ -349,6 +364,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 if (deployHostedEngine != null) {
                     uriBuilder.addParameter("deploy_hosted_engine", XmlWriter.renderBoolean(deployHostedEngine));
                 }
+                if (reboot != null) {
+                    uriBuilder.addParameter("reboot", XmlWriter.renderBoolean(reboot));
+                }
                 if (undeployHostedEngine != null) {
                     uriBuilder.addParameter("undeploy_hosted_engine", XmlWriter.renderBoolean(undeployHostedEngine));
                 }
@@ -449,6 +467,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             return this;
         }
         
+        private Boolean reboot;
+        public AddUsingSshRequest reboot(Boolean reboot) {
+            this.reboot = reboot;
+            return this;
+        }
+        
         private Boolean undeployHostedEngine;
         public AddUsingSshRequest undeployHostedEngine(Boolean undeployHostedEngine) {
             this.undeployHostedEngine = undeployHostedEngine;
@@ -465,6 +489,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 if (deployHostedEngine != null) {
                     uriBuilder.addParameter("deploy_hosted_engine", XmlWriter.renderBoolean(deployHostedEngine));
                 }
+                if (reboot != null) {
+                    uriBuilder.addParameter("reboot", XmlWriter.renderBoolean(reboot));
+                }
                 if (undeployHostedEngine != null) {
                     uriBuilder.addParameter("undeploy_hosted_engine", XmlWriter.renderBoolean(undeployHostedEngine));
                 }
