@@ -46,6 +46,7 @@ import org.ovirt.engine.sdk4.services.DomainsService;
 import org.ovirt.engine.sdk4.services.EngineKatelloErrataService;
 import org.ovirt.engine.sdk4.services.EventsService;
 import org.ovirt.engine.sdk4.services.ExternalHostProvidersService;
+import org.ovirt.engine.sdk4.services.ExternalTemplateImportsService;
 import org.ovirt.engine.sdk4.services.ExternalVmImportsService;
 import org.ovirt.engine.sdk4.services.GroupsService;
 import org.ovirt.engine.sdk4.services.HostsService;
@@ -121,7 +122,9 @@ public class SystemServiceImpl extends ServiceImpl implements SystemService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlApiReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.api(XmlApiReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -132,7 +135,7 @@ public class SystemServiceImpl extends ServiceImpl implements SystemService {
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -141,7 +144,7 @@ public class SystemServiceImpl extends ServiceImpl implements SystemService {
     private class GetResponseImpl implements GetResponse {
         private Api api;
         
-        public GetResponseImpl(Api api) {
+        public void api(Api api) {
             this.api = api;
         }
         
@@ -243,6 +246,10 @@ public class SystemServiceImpl extends ServiceImpl implements SystemService {
         return new ExternalHostProvidersServiceImpl(getConnection(), getPath() + "/externalhostproviders");
     }
     
+    public ExternalTemplateImportsService externalTemplateImportsService() {
+        return new ExternalTemplateImportsServiceImpl(getConnection(), getPath() + "/externaltemplateimports");
+    }
+    
     public ExternalVmImportsService externalVmImportsService() {
         return new ExternalVmImportsServiceImpl(getConnection(), getPath() + "/externalvmimports");
     }
@@ -426,6 +433,12 @@ public class SystemServiceImpl extends ServiceImpl implements SystemService {
         if (path.startsWith("externalhostproviders/")) {
             return externalHostProvidersService().service(path.substring(22));
         }
+        if (path.equals("externaltemplateimports")) {
+            return externalTemplateImportsService();
+        }
+        if (path.startsWith("externaltemplateimports/")) {
+            return externalTemplateImportsService().service(path.substring(24));
+        }
         if (path.equals("externalvmimports")) {
             return externalVmImportsService();
         }
