@@ -57,7 +57,9 @@ import org.ovirt.engine.sdk4.services.KatelloErrataService;
 import org.ovirt.engine.sdk4.services.SnapshotsService;
 import org.ovirt.engine.sdk4.services.StatisticsService;
 import org.ovirt.engine.sdk4.services.VmApplicationsService;
+import org.ovirt.engine.sdk4.services.VmBackupsService;
 import org.ovirt.engine.sdk4.services.VmCdromsService;
+import org.ovirt.engine.sdk4.services.VmCheckpointsService;
 import org.ovirt.engine.sdk4.services.VmGraphicsConsolesService;
 import org.ovirt.engine.sdk4.services.VmHostDevicesService;
 import org.ovirt.engine.sdk4.services.VmNicsService;
@@ -83,6 +85,57 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
         super(connection, path);
     }
     
+    private class AutoPinCpuAndNumaNodesRequestImpl extends BaseRequest<AutoPinCpuAndNumaNodesRequest, AutoPinCpuAndNumaNodesResponse> implements AutoPinCpuAndNumaNodesRequest {
+        private Boolean async;
+        public AutoPinCpuAndNumaNodesRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        private Boolean optimizeCpuSettings;
+        public AutoPinCpuAndNumaNodesRequest optimizeCpuSettings(Boolean optimizeCpuSettings) {
+            this.optimizeCpuSettings = optimizeCpuSettings;
+            return this;
+        }
+        
+        public AutoPinCpuAndNumaNodesResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/autopincpuandnumanodes");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                action.optimizeCpuSettings(optimizeCpuSettings);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new AutoPinCpuAndNumaNodesResponseImpl();
+        }
+        
+    }
+    
+    private class AutoPinCpuAndNumaNodesResponseImpl implements AutoPinCpuAndNumaNodesResponse {
+    }
+    
+    public AutoPinCpuAndNumaNodesRequest autoPinCpuAndNumaNodes() {
+        return new AutoPinCpuAndNumaNodesRequestImpl();
+    }
+    
     private class CancelMigrationRequestImpl extends BaseRequest<CancelMigrationRequest, CancelMigrationResponse> implements CancelMigrationRequest {
         private Boolean async;
         public CancelMigrationRequest async(Boolean async) {
@@ -134,6 +187,23 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean discardSnapshots;
+        public CloneRequest discardSnapshots(Boolean discardSnapshots) {
+            this.discardSnapshots = discardSnapshots;
+            return this;
+        }
+        
+        private StorageDomain storageDomain;
+        public CloneRequest storageDomain(StorageDomain storageDomain) {
+            this.storageDomain = storageDomain;
+            return this;
+        }
+        
+        public CloneRequest storageDomain(StorageDomainBuilder storageDomain) {
+            this.storageDomain = storageDomain.build();
+            return this;
+        }
+        
         private Vm vm;
         public CloneRequest vm(Vm vm) {
             this.vm = vm;
@@ -153,6 +223,8 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             ) {
                 ActionBuilder action = new ActionBuilder();
                 action.async(async);
+                action.discardSnapshots(discardSnapshots);
+                action.storageDomain(storageDomain);
                 action.vm(vm);
                 XmlActionWriter.writeOne(action.build(), xmlWriter);
                 xmlWriter.flush();
@@ -410,6 +482,12 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean ovfAsOva;
+        public GetRequest ovfAsOva(Boolean ovfAsOva) {
+            this.ovfAsOva = ovfAsOva;
+            return this;
+        }
+        
         public GetResponse send() {
             HttpGet request = null;
             try {
@@ -426,6 +504,9 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
                 if (nextRun != null) {
                     uriBuilder.addParameter("next_run", XmlWriter.renderBoolean(nextRun));
                 }
+                if (ovfAsOva != null) {
+                    uriBuilder.addParameter("ovf_as_ova", XmlWriter.renderBoolean(ovfAsOva));
+                }
                 if (query != null) {
                     for (Map.Entry<String, String> queryParam : query.entrySet()) {
                         uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
@@ -616,6 +697,12 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean migrateVmsInAffinityClosure;
+        public MigrateRequest migrateVmsInAffinityClosure(Boolean migrateVmsInAffinityClosure) {
+            this.migrateVmsInAffinityClosure = migrateVmsInAffinityClosure;
+            return this;
+        }
+        
         public MigrateResponse send() {
             HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/migrate");
             try (
@@ -627,6 +714,7 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
                 action.cluster(cluster);
                 action.force(force);
                 action.host(host);
+                action.migrateVmsInAffinityClosure(migrateVmsInAffinityClosure);
                 XmlActionWriter.writeOne(action.build(), xmlWriter);
                 xmlWriter.flush();
                 request.setEntity(new ByteArrayEntity(output.toByteArray()));
@@ -770,6 +858,12 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean force;
+        public RebootRequest force(Boolean force) {
+            this.force = force;
+            return this;
+        }
+        
         public RebootResponse send() {
             HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/reboot");
             try (
@@ -778,6 +872,7 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             ) {
                 ActionBuilder action = new ActionBuilder();
                 action.async(async);
+                action.force(force);
                 XmlActionWriter.writeOne(action.build(), xmlWriter);
                 xmlWriter.flush();
                 request.setEntity(new ByteArrayEntity(output.toByteArray()));
@@ -922,6 +1017,50 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
         return new ReorderMacAddressesRequestImpl();
     }
     
+    private class ResetRequestImpl extends BaseRequest<ResetRequest, ResetResponse> implements ResetRequest {
+        private Boolean async;
+        public ResetRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        public ResetResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/reset");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new ResetResponseImpl();
+        }
+        
+    }
+    
+    private class ResetResponseImpl implements ResetResponse {
+    }
+    
+    public ResetRequest reset() {
+        return new ResetRequestImpl();
+    }
+    
     private class ShutdownRequestImpl extends BaseRequest<ShutdownRequest, ShutdownResponse> implements ShutdownRequest {
         private Boolean async;
         public ShutdownRequest async(Boolean async) {
@@ -929,6 +1068,18 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean force;
+        public ShutdownRequest force(Boolean force) {
+            this.force = force;
+            return this;
+        }
+        
+        private String reason;
+        public ShutdownRequest reason(String reason) {
+            this.reason = reason;
+            return this;
+        }
+        
         public ShutdownResponse send() {
             HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/shutdown");
             try (
@@ -937,6 +1088,8 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             ) {
                 ActionBuilder action = new ActionBuilder();
                 action.async(async);
+                action.force(force);
+                action.reason(reason);
                 XmlActionWriter.writeOne(action.build(), xmlWriter);
                 xmlWriter.flush();
                 request.setEntity(new ByteArrayEntity(output.toByteArray()));
@@ -1002,6 +1155,18 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean useIgnition;
+        public StartRequest useIgnition(Boolean useIgnition) {
+            this.useIgnition = useIgnition;
+            return this;
+        }
+        
+        private Boolean useInitialization;
+        public StartRequest useInitialization(Boolean useInitialization) {
+            this.useInitialization = useInitialization;
+            return this;
+        }
+        
         private Boolean useSysprep;
         public StartRequest useSysprep(Boolean useSysprep) {
             this.useSysprep = useSysprep;
@@ -1037,6 +1202,8 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
                 action.filter(filter);
                 action.pause(pause);
                 action.useCloudInit(useCloudInit);
+                action.useIgnition(useIgnition);
+                action.useInitialization(useInitialization);
                 action.useSysprep(useSysprep);
                 action.vm(vm);
                 action.volatile_(volatile_);
@@ -1076,6 +1243,18 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean force;
+        public StopRequest force(Boolean force) {
+            this.force = force;
+            return this;
+        }
+        
+        private String reason;
+        public StopRequest reason(String reason) {
+            this.reason = reason;
+            return this;
+        }
+        
         public StopResponse send() {
             HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/stop");
             try (
@@ -1084,6 +1263,8 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
             ) {
                 ActionBuilder action = new ActionBuilder();
                 action.async(async);
+                action.force(force);
+                action.reason(reason);
                 XmlActionWriter.writeOne(action.build(), xmlWriter);
                 xmlWriter.flush();
                 request.setEntity(new ByteArrayEntity(output.toByteArray()));
@@ -1592,10 +1773,18 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
         return new VmApplicationsServiceImpl(getConnection(), getPath() + "/applications");
     }
     
+    public VmBackupsService backupsService() {
+        return new VmBackupsServiceImpl(getConnection(), getPath() + "/backups");
+    }
+    
     public VmCdromsService cdromsService() {
         return new VmCdromsServiceImpl(getConnection(), getPath() + "/cdroms");
     }
     
+    public VmCheckpointsService checkpointsService() {
+        return new VmCheckpointsServiceImpl(getConnection(), getPath() + "/checkpoints");
+    }
+    
     public DiskAttachmentsService diskAttachmentsService() {
         return new DiskAttachmentsServiceImpl(getConnection(), getPath() + "/diskattachments");
     }
@@ -1665,12 +1854,24 @@ public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
         if (path.startsWith("applications/")) {
             return applicationsService().service(path.substring(13));
         }
+        if (path.equals("backups")) {
+            return backupsService();
+        }
+        if (path.startsWith("backups/")) {
+            return backupsService().service(path.substring(8));
+        }
         if (path.equals("cdroms")) {
             return cdromsService();
         }
         if (path.startsWith("cdroms/")) {
             return cdromsService().service(path.substring(7));
         }
+        if (path.equals("checkpoints")) {
+            return checkpointsService();
+        }
+        if (path.startsWith("checkpoints/")) {
+            return checkpointsService().service(path.substring(12));
+        }
         if (path.equals("diskattachments")) {
             return diskAttachmentsService();
         }
