@@ -64,6 +64,9 @@ public class XmlClusterReader {
                 case "ballooning_enabled":
                 object.ballooningEnabled(reader.readBoolean());
                 break;
+                case "bios_type":
+                object.biosType(XmlBiosTypeReader.readOne(reader));
+                break;
                 case "comment":
                 object.comment(reader.readString());
                 break;
@@ -97,6 +100,9 @@ public class XmlClusterReader {
                 case "fencing_policy":
                 object.fencingPolicy(XmlFencingPolicyReader.readOne(reader));
                 break;
+                case "fips_mode":
+                object.fipsMode(XmlFipsModeReader.readOne(reader));
+                break;
                 case "firewall_type":
                 object.firewallType(XmlFirewallTypeReader.readOne(reader));
                 break;
@@ -118,6 +124,12 @@ public class XmlClusterReader {
                 case "ksm":
                 object.ksm(XmlKsmReader.readOne(reader));
                 break;
+                case "log_max_memory_used_threshold":
+                object.logMaxMemoryUsedThreshold(reader.readInteger());
+                break;
+                case "log_max_memory_used_threshold_type":
+                object.logMaxMemoryUsedThresholdType(XmlLogMaxMemoryUsedThresholdTypeReader.readOne(reader));
+                break;
                 case "mac_pool":
                 object.macPool(XmlMacPoolReader.readOne(reader));
                 break;
@@ -178,6 +190,9 @@ public class XmlClusterReader {
                 case "virt_service":
                 object.virtService(reader.readBoolean());
                 break;
+                case "vnc_encryption":
+                object.vncEncryption(reader.readBoolean());
+                break;
                 case "link":
                 // Process the attributes:
                 String rel = reader.getAttributeValue("rel");
