@@ -91,6 +91,9 @@ public class XmlUserReader {
                 case "namespace":
                 object.namespace(reader.readString());
                 break;
+                case "options":
+                object.options(XmlUserOptionReader.readMany(reader));
+                break;
                 case "password":
                 object.password(reader.readString());
                 break;
@@ -198,6 +201,11 @@ public class XmlUserReader {
                 list.href(href);
                 object.groups(list);
                 break;
+                case "options":
+                list = new ArrayListWithHref(object.options());
+                list.href(href);
+                object.options(list);
+                break;
                 case "permissions":
                 list = new ArrayListWithHref(object.permissions());
                 list.href(href);
