@@ -58,6 +58,9 @@ public class XmlVmBaseReader {
         while (reader.forward()) {
             String name = reader.getLocalName();
             switch (name) {
+                case "auto_pinning_policy":
+                object.autoPinningPolicy(XmlAutoPinningPolicyReader.readOne(reader));
+                break;
                 case "bios":
                 object.bios(XmlBiosReader.readOne(reader));
                 break;
@@ -181,6 +184,9 @@ public class XmlVmBaseReader {
                 case "time_zone":
                 object.timeZone(XmlTimeZoneReader.readOne(reader));
                 break;
+                case "tpm_enabled":
+                object.tpmEnabled(reader.readBoolean());
+                break;
                 case "tunnel_migration":
                 object.tunnelMigration(reader.readBoolean());
                 break;
@@ -193,6 +199,12 @@ public class XmlVmBaseReader {
                 case "virtio_scsi":
                 object.virtioScsi(XmlVirtioScsiReader.readOne(reader));
                 break;
+                case "virtio_scsi_multi_queues":
+                object.virtioScsiMultiQueues(reader.readInteger());
+                break;
+                case "virtio_scsi_multi_queues_enabled":
+                object.virtioScsiMultiQueuesEnabled(reader.readBoolean());
+                break;
                 case "link":
                 // Process the attributes:
                 String rel = reader.getAttributeValue("rel");
