@@ -64,6 +64,9 @@ public class XmlVmReader {
                 case "applications":
                 object.applications(XmlApplicationReader.readMany(reader));
                 break;
+                case "auto_pinning_policy":
+                object.autoPinningPolicy(XmlAutoPinningPolicyReader.readOne(reader));
+                break;
                 case "bios":
                 object.bios(XmlBiosReader.readOne(reader));
                 break;
@@ -283,6 +286,9 @@ public class XmlVmReader {
                 case "time_zone":
                 object.timeZone(XmlTimeZoneReader.readOne(reader));
                 break;
+                case "tpm_enabled":
+                object.tpmEnabled(reader.readBoolean());
+                break;
                 case "tunnel_migration":
                 object.tunnelMigration(reader.readBoolean());
                 break;
@@ -298,6 +304,12 @@ public class XmlVmReader {
                 case "virtio_scsi":
                 object.virtioScsi(XmlVirtioScsiReader.readOne(reader));
                 break;
+                case "virtio_scsi_multi_queues":
+                object.virtioScsiMultiQueues(reader.readInteger());
+                break;
+                case "virtio_scsi_multi_queues_enabled":
+                object.virtioScsiMultiQueuesEnabled(reader.readBoolean());
+                break;
                 case "vm_pool":
                 object.vmPool(XmlVmPoolReader.readOne(reader));
                 break;
