@@ -42,6 +42,10 @@ public interface DiskSnapshotsService extends Service {
          * If true return also active snapshots. If not specified active snapshots are not returned.
          */
         ListRequest includeActive(Boolean includeActive);
+        /**
+         * If true return also template snapshots. If not specified template snapshots are not returned.
+         */
+        ListRequest includeTemplate(Boolean includeTemplate);
         /**
          * Sets the maximum number of snapshots to return. If not specified all the snapshots are returned.
          */
