@@ -20,6 +20,10 @@ import java.math.BigInteger;
 import java.util.List;
 
 public interface Action extends Identified {
+    boolean activate();
+    
+    boolean activatePresent();
+    
     boolean allowPartialImport();
     
     boolean allowPartialImportPresent();
@@ -36,6 +40,10 @@ public interface Action extends Identified {
     
     boolean authorizedKeyPresent();
     
+    AutoPinningPolicy autoPinningPolicy();
+    
+    boolean autoPinningPolicyPresent();
+    
     List<GlusterBrick> bricks();
     
     boolean bricksPresent();
@@ -64,6 +72,10 @@ public interface Action extends Identified {
     
     boolean collapseSnapshotsPresent();
     
+    boolean commitOnSuccess();
+    
+    boolean commitOnSuccessPresent();
+    
     StorageConnection connection();
     
     boolean connectionPresent();
@@ -184,10 +196,18 @@ public interface Action extends Identified {
     
     boolean logicalUnitsPresent();
     
+    boolean maintenanceAfterRestart();
+    
+    boolean maintenanceAfterRestartPresent();
+    
     boolean maintenanceEnabled();
     
     boolean maintenanceEnabledPresent();
     
+    boolean migrateVmsInAffinityClosure();
+    
+    boolean migrateVmsInAffinityClosurePresent();
+    
     List<HostNic> modifiedBonds();
     
     boolean modifiedBondsPresent();
@@ -200,6 +220,10 @@ public interface Action extends Identified {
     
     boolean modifiedNetworkAttachmentsPresent();
     
+    boolean optimizeCpuSettings();
+    
+    boolean optimizeCpuSettingsPresent();
+    
     Option option();
     
     boolean optionPresent();
@@ -276,6 +300,10 @@ public interface Action extends Identified {
     
     boolean snapshotPresent();
     
+    Host sourceHost();
+    
+    boolean sourceHostPresent();
+    
     Ssh ssh();
     
     boolean sshPresent();
@@ -312,14 +340,34 @@ public interface Action extends Identified {
     
     boolean ticketPresent();
     
+    BigInteger timeout();
+    Byte timeoutAsByte();
+    Short timeoutAsShort();
+    Integer timeoutAsInteger();
+    Long timeoutAsLong();
+    
+    boolean timeoutPresent();
+    
     boolean undeployHostedEngine();
     
     boolean undeployHostedEnginePresent();
     
+    ClusterUpgradeAction upgradeAction();
+    
+    boolean upgradeActionPresent();
+    
     boolean useCloudInit();
     
     boolean useCloudInitPresent();
     
+    boolean useIgnition();
+    
+    boolean useIgnitionPresent();
+    
+    boolean useInitialization();
+    
+    boolean useInitializationPresent();
+    
     boolean useSysprep();
     
     boolean useSysprepPresent();
