@@ -28,6 +28,10 @@ public interface Backup extends Identified {
     
     boolean fromCheckpointIdPresent();
     
+    Date modificationDate();
+    
+    boolean modificationDatePresent();
+    
     BackupPhase phase();
     
     boolean phasePresent();
