@@ -21,4 +21,8 @@ public interface Bios {
     
     boolean bootMenuPresent();
     
+    BiosType type();
+    
+    boolean typePresent();
+    
 }
