@@ -21,4 +21,8 @@ public interface DiskSnapshot extends Disk {
     
     boolean diskPresent();
     
+    DiskSnapshot parent();
+    
+    boolean parentPresent();
+    
 }
