@@ -66,6 +66,10 @@ public interface VmPool extends Identified {
     
     boolean statefulPresent();
     
+    boolean tpmEnabled();
+    
+    boolean tpmEnabledPresent();
+    
     VmPoolType type();
     
     boolean typePresent();
